@@ -334,9 +334,10 @@ class Job:
         if self._volumes:
             for vol in self._volumes:
                 if vol.persistent_volume_claim:
-                    response = api_request(core_api.delete_namespaced_persistent_volume_claim,
-                                            namespace=self.namespace,
-                                            name=vol.persistent_volume_claim.claim_name)
+                    if not self.workspace_vc or self.workspace_vc.shared and vol.persistent_volume_claim.claim_name == self.workspace_vc.name:
+                        response = api_request(core_api.delete_namespaced_persistent_volume_claim,
+                                                namespace=self.namespace,
+                                                name=vol.persistent_volume_claim.claim_name)
 
     def create(self, job_spec=None, pod_spec=None):
         """Creates and runs the job on the cluster.
@@ -437,7 +438,7 @@ class WorkspaceJob(Job):
                     client.V1VolumeMount(mount_path=self.outputs_path, name="outputs"),
                 )
         else:
-            self.workspace_vc = VolumeClaim(self.shared_claim_name, self.workspace_size, self.namespace, "filestore-hdd", ['ReadWriteMany'])
+            self.workspace_vc = VolumeClaim(self.shared_claim_name, self.workspace_size, self.namespace, "filestore-hdd", ['ReadWriteMany'], True)
             self.add_volume(
                 name="workspace",
                 persistent_volume_claim=client.V1PersistentVolumeClaimVolumeSource(
